package com.doc.biz.controller;

import com.doc.biz.domain.DocActorUser;
import com.doc.biz.service.IDocActorUserService;
import com.doc.common.annotation.Log;
import com.doc.common.core.controller.BaseController;
import com.doc.common.core.domain.AjaxResult;
import com.doc.common.core.page.TableDataInfo;
import com.doc.common.enums.BusinessType;
import com.doc.common.utils.poi.ExcelUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 文档协作成员Controller
 *
 * @author wukai
 * @date 2023-09-18
 */
//@Api(tags = "文档协作成员")
@RestController
@RequestMapping("/biz/actorUser")
public class DocActorUserController extends BaseController {
    @Resource
    private IDocActorUserService docActorUserService;

    /**
     * 查询文档协作成员列表
     */
    //@ApiOperation("查询文档协作成员列表")
    @PreAuthorize("@ss.hasPermi('biz:actorUser:list')")
    @GetMapping("/list")
    public TableDataInfo list(DocActorUser docActorUser) {
        startPage();
        List<DocActorUser> list = docActorUserService.selectDocActorUserList(docActorUser);
        return getDataTable(list);
    }

    /**
     * 导出文档协作成员列表
     */
    //@ApiOperation("导出文档协作成员列表")
    @PreAuthorize("@ss.hasPermi('biz:actorUser:export')")
    @Log(title = "文档协作成员", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DocActorUser docActorUser) {
        List<DocActorUser> list = docActorUserService.selectDocActorUserList(docActorUser);
        ExcelUtil<DocActorUser> util = new ExcelUtil<DocActorUser>(DocActorUser.class);
        util.exportExcel(response, list, "文档协作成员数据");
    }

    /**
     * 获取文档协作成员详细信息
     */
    //@ApiOperation("获取文档协作成员详细信息")
    @PreAuthorize("@ss.hasPermi('biz:actorUser:query')")
    @GetMapping(value = "/{docId}")
    public AjaxResult getInfo(@PathVariable("docId") Long docId) {
        return success(docActorUserService.selectDocActorUserByDocId(docId));
    }

    /**
     * 新增文档协作成员
     */
    //@ApiOperation("新增文档协作成员")
    @PreAuthorize("@ss.hasPermi('biz:actorUser:add')")
    @Log(title = "文档协作成员", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DocActorUser docActorUser) {
        return toAjax(docActorUserService.insertDocActorUser(docActorUser));
    }

    /**
     * 修改文档协作成员
     */
    //@ApiOperation("修改文档协作成员")
    @PreAuthorize("@ss.hasPermi('biz:actorUser:edit')")
    @Log(title = "文档协作成员", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DocActorUser docActorUser) {
        return toAjax(docActorUserService.updateDocActorUser(docActorUser));
    }

    /**
     * 删除文档协作成员
     */
    //@ApiOperation("删除文档协作成员")
    @PreAuthorize("@ss.hasPermi('biz:actorUser:remove')")
    @Log(title = "文档协作成员", businessType = BusinessType.DELETE)
    @DeleteMapping("/{docIds}")
    public AjaxResult remove(@PathVariable Long[] docIds) {
        return toAjax(docActorUserService.deleteDocActorUserByDocIds(docIds));
    }
}
