package com.doc.biz.service.impl;

import com.doc.biz.domain.DocFavorite;
import com.doc.biz.mapper.DocFavoriteMapper;
import com.doc.biz.service.IDocFavoriteService;
import com.doc.common.utils.DateUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * 文件收藏Service业务层处理
 *
 * @author wukai
 * @date 2023-08-15
 */
@Service
public class DocFavoriteServiceImpl implements IDocFavoriteService {
    @Resource
    private DocFavoriteMapper docFavoriteMapper;

    /**
     * 查询文件收藏
     *
     * @param favoriteId 文件收藏主键
     * @return 文件收藏
     */
    @Override
    public DocFavorite selectDocFavoriteByFavoriteId(Long favoriteId) {
        return docFavoriteMapper.selectDocFavoriteByFavoriteId(favoriteId);
    }

    /**
     * 查询文件收藏列表
     *
     * @param docFavorite 文件收藏
     * @return 文件收藏
     */
    @Override
    public List<DocFavorite> selectDocFavoriteList(DocFavorite docFavorite) {
        return docFavoriteMapper.selectDocFavoriteList(docFavorite);
    }

    /**
     * 新增文件收藏
     *
     * @param docFavorite 文件收藏
     * @return 结果
     */
    @Override
    public int insertDocFavorite(DocFavorite docFavorite) {
        docFavorite.setCreateTime(DateUtils.getNowDate());
        return docFavoriteMapper.insertDocFavorite(docFavorite);
    }

    /**
     * 修改文件收藏
     *
     * @param docFavorite 文件收藏
     * @return 结果
     */
    @Override
    public int updateDocFavorite(DocFavorite docFavorite) {
        docFavorite.setUpdateTime(DateUtils.getNowDate());
        return docFavoriteMapper.updateDocFavorite(docFavorite);
    }

    /**
     * 批量删除文件收藏
     *
     * @param favoriteIds 需要删除的文件收藏主键
     * @return 结果
     */
    @Override
    public int deleteDocFavoriteByFavoriteIds(Long[] favoriteIds) {
        return docFavoriteMapper.deleteDocFavoriteByFavoriteIds(favoriteIds);
    }

    /**
     * 删除文件收藏信息
     *
     * @param favoriteId 文件收藏主键
     * @return 结果
     */
    @Override
    public int deleteDocFavoriteByFavoriteId(Long favoriteId) {
        return docFavoriteMapper.deleteDocFavoriteByFavoriteId(favoriteId);
    }
}
